==> syncope-2.0.12-source-release.zip: syncope-2.0.12/common/lib/src/main/java/org/apache/syncope/common/lib/to/AnyTypeTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.to;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.ArrayList;
import java.util.List;
import javax.ws.rs.PathParam;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.syncope.common.lib.AbstractBaseBean;
import org.apache.syncope.common.lib.types.AnyTypeKind;

@XmlRootElement(name = "anyType")
@XmlType
public class AnyTypeTO extends AbstractBaseBean implements EntityTO {

    private static final long serialVersionUID = 6771657557616874373L;

    private String key;

    private AnyTypeKind kind;

    private final List<String> classes = new ArrayList<>();

    @Override
    public String getKey() {
        return key;
    }

    @PathParam("key")
    @Override
    public void setKey(final String key) {
        this.key = key;
    }

    public AnyTypeKind getKind() {
        return kind;
    }

    public void setKind(final AnyTypeKind kind) {
        this.kind = kind;
    }

    @XmlElementWrapper(name = "classes")
    @XmlElement(name = "class")
    @JsonProperty("classes")
    public List<String> getClasses() {
        return classes;
    }

}

==> syncope-2.1.3-source-release.zip: syncope-2.1.3/common/lib/src/main/java/org/apache/syncope/common/lib/to/AnyTypeTO.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.common.lib.to;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.ArrayList;
import java.util.List;
import javax.ws.rs.PathParam;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.syncope.common.lib.types.AnyTypeKind;

@XmlRootElement(name = "anyType")
@XmlType
public class AnyTypeTO implements EntityTO {

    private static final long serialVersionUID = 6771657557616874373L;

    private String key;

    private AnyTypeKind kind;

    private final List<String> classes = new ArrayList<>();

    @Override
    public String getKey() {
        return key;
    }

    @PathParam("key")
    @Override
    public void setKey(final String key) {
        this.key = key;
    }

    public AnyTypeKind getKind() {
        return kind;
    }

    public void setKind(final AnyTypeKind kind) {
        this.kind = kind;
    }

    @XmlElementWrapper(name = "classes")
    @XmlElement(name = "class")
    @JsonProperty("classes")
    public List<String> getClasses() {
        return classes;
    }

}
